@@ -25,9 +25,28 @@
 #include <gee/arraylist.h>
 #include <string.h>
 
+
+#define GEE_ARRAY_LIST_TYPE_ITERATOR (gee_array_list_iterator_get_type ())
+#define GEE_ARRAY_LIST_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_ARRAY_LIST_TYPE_ITERATOR, GeeArrayListIterator))
+#define GEE_ARRAY_LIST_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_ARRAY_LIST_TYPE_ITERATOR, GeeArrayListIteratorClass))
+#define GEE_ARRAY_LIST_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_ARRAY_LIST_TYPE_ITERATOR))
+#define GEE_ARRAY_LIST_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_ARRAY_LIST_TYPE_ITERATOR))
+#define GEE_ARRAY_LIST_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_ARRAY_LIST_TYPE_ITERATOR, GeeArrayListIteratorClass))
+
 typedef struct _GeeArrayListIterator GeeArrayListIterator;
 typedef struct _GeeArrayListIteratorClass GeeArrayListIteratorClass;
 typedef struct _GeeArrayListIteratorPrivate GeeArrayListIteratorPrivate;
+
+struct _GeeArrayListIterator {
+	GObject parent_instance;
+	GeeArrayListIteratorPrivate * priv;
+	gint _stamp;
+};
+struct _GeeArrayListIteratorClass {
+	GObjectClass parent_class;
+};
+
+
 struct _GeeArrayListPrivate {
 	gpointer* _items;
 	gint _items_length1;
@@ -61,22 +80,6 @@ static void gee_array_list_real_clear (GeeCollection* base);
 static void gee_array_list_shift (GeeArrayList* self, gint start, gint delta);
 static void gee_array_list_grow_if_needed (GeeArrayList* self, gint new_count);
 static void gee_array_list_set_capacity (GeeArrayList* self, gint value);
-
-#define GEE_ARRAY_LIST_TYPE_ITERATOR (gee_array_list_iterator_get_type ())
-#define GEE_ARRAY_LIST_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_ARRAY_LIST_TYPE_ITERATOR, GeeArrayListIterator))
-#define GEE_ARRAY_LIST_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_ARRAY_LIST_TYPE_ITERATOR, GeeArrayListIteratorClass))
-#define GEE_ARRAY_LIST_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_ARRAY_LIST_TYPE_ITERATOR))
-#define GEE_ARRAY_LIST_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_ARRAY_LIST_TYPE_ITERATOR))
-#define GEE_ARRAY_LIST_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_ARRAY_LIST_TYPE_ITERATOR, GeeArrayListIteratorClass))
-
-struct _GeeArrayListIterator {
-	GObject parent_instance;
-	GeeArrayListIteratorPrivate * priv;
-	gint _stamp;
-};
-struct _GeeArrayListIteratorClass {
-	GObjectClass parent_class;
-};
 struct _GeeArrayListIteratorPrivate {
 	GeeArrayList* _list;
 	gint _index;
@@ -109,13 +112,32 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 static void _vala_array_move (gpointer array, gsize element_size, gint src, gint dest, gint length);
 
 
+
 GeeArrayList* gee_array_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeArrayList * self;
-	self = g_object_newv (GEE_TYPE_ARRAY_LIST, 0, NULL);
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_TYPE_ARRAY_LIST, __params_it - __params, __params);
 	gee_array_list_set_equal_func (self, equal_func);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -147,7 +169,7 @@ static gint gee_array_list_real_index_of (GeeList* base, gconstpointer item) {
 	{
 		gint index;
 		index = 0;
-		for (index = 0; index < self->priv->_size; index++) {
+		for (; index < self->priv->_size; index++) {
 			if (self->priv->_equal_func (self->priv->_items[index], item)) {
 				return index;
 			}
@@ -162,6 +184,7 @@ static gpointer gee_array_list_real_get (GeeList* base, gint index) {
 	gconstpointer _tmp0;
 	self = GEE_ARRAY_LIST (base);
 	g_assert (index >= 0 && index < self->priv->_size);
+	_tmp0 = NULL;
 	return (_tmp0 = self->priv->_items[index], (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0))));
 }
 
@@ -172,6 +195,8 @@ static void gee_array_list_real_set (GeeList* base, gint index, gconstpointer it
 	gconstpointer _tmp0;
 	self = GEE_ARRAY_LIST (base);
 	g_assert (index >= 0 && index < self->priv->_size);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
 	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0)))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
 }
 
@@ -185,6 +210,8 @@ static gboolean gee_array_list_real_add (GeeCollection* base, gconstpointer item
 	if (self->priv->_size == self->priv->_items_length1) {
 		gee_array_list_grow_if_needed (self, 1);
 	}
+	_tmp1 = NULL;
+	_tmp0 = NULL;
 	_tmp2 = self->priv->_size++;
 	self->priv->_items[_tmp2] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0)))), (self->priv->_items[_tmp2] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[_tmp2] = (self->priv->g_destroy_func (self->priv->_items[_tmp2]), NULL))), _tmp1);
 	self->priv->_stamp++;
@@ -202,6 +229,8 @@ static void gee_array_list_real_insert (GeeList* base, gint index, gconstpointer
 		gee_array_list_grow_if_needed (self, 1);
 	}
 	gee_array_list_shift (self, index, 1);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
 	self->priv->_items[index] = (_tmp1 = (_tmp0 = item, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0)))), (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp1);
 	self->priv->_stamp++;
 }
@@ -213,7 +242,7 @@ static gboolean gee_array_list_real_remove (GeeCollection* base, gconstpointer i
 	{
 		gint index;
 		index = 0;
-		for (index = 0; index < self->priv->_size; index++) {
+		for (; index < self->priv->_size; index++) {
 			if (self->priv->_equal_func (self->priv->_items[index], item)) {
 				gee_list_remove_at (GEE_LIST (self), index);
 				return TRUE;
@@ -229,6 +258,7 @@ static void gee_array_list_real_remove_at (GeeList* base, gint index) {
 	gpointer _tmp0;
 	self = GEE_ARRAY_LIST (base);
 	g_assert (index >= 0 && index < self->priv->_size);
+	_tmp0 = NULL;
 	self->priv->_items[index] = (_tmp0 = NULL, (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp0);
 	gee_array_list_shift (self, index + 1, -1);
 	self->priv->_stamp++;
@@ -241,8 +271,9 @@ static void gee_array_list_real_clear (GeeCollection* base) {
 	{
 		gint index;
 		index = 0;
-		for (index = 0; index < self->priv->_size; index++) {
+		for (; index < self->priv->_size; index++) {
 			gpointer _tmp0;
+			_tmp0 = NULL;
 			self->priv->_items[index] = (_tmp0 = NULL, (self->priv->_items[index] == NULL || self->priv->g_destroy_func == NULL ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL))), _tmp0);
 		}
 	}
@@ -295,13 +326,31 @@ void gee_array_list_set_equal_func (GeeArrayList* self, GEqualFunc value) {
 
 
 static GeeArrayListIterator* gee_array_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeArrayListIterator * self;
-	g_return_val_if_fail (list == NULL || GEE_IS_ARRAY_LIST (list), NULL);
-	self = g_object_newv (GEE_ARRAY_LIST_TYPE_ITERATOR, 0, NULL);
+	g_return_val_if_fail (GEE_IS_ARRAY_LIST (list), NULL);
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_ARRAY_LIST_TYPE_ITERATOR, __params_it - __params, __params);
 	gee_array_list_iterator_set_list (self, list);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -379,9 +428,9 @@ static void gee_array_list_iterator_class_init (GeeArrayListIteratorClass * klas
 	G_OBJECT_CLASS (klass)->get_property = gee_array_list_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_array_list_iterator_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_array_list_iterator_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_ITERATOR_LIST, g_param_spec_object ("list", "list", "list", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
@@ -463,9 +512,9 @@ static void gee_array_list_class_init (GeeArrayListClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = gee_array_list_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_array_list_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_array_list_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_SIZE, "size");
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_ARRAY_LIST_EQUAL_FUNC, g_param_spec_pointer ("equal-func", "equal-func", "equal-func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
