@@ -25,9 +25,32 @@
 #include <gee/hashset.h>
 
 typedef struct _GeeHashSetNode GeeHashSetNode;
+
+#define GEE_HASH_SET_TYPE_ITERATOR (gee_hash_set_iterator_get_type ())
+#define GEE_HASH_SET_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_HASH_SET_TYPE_ITERATOR, GeeHashSetIterator))
+#define GEE_HASH_SET_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_HASH_SET_TYPE_ITERATOR, GeeHashSetIteratorClass))
+#define GEE_HASH_SET_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_HASH_SET_TYPE_ITERATOR))
+#define GEE_HASH_SET_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_HASH_SET_TYPE_ITERATOR))
+#define GEE_HASH_SET_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_HASH_SET_TYPE_ITERATOR, GeeHashSetIteratorClass))
+
 typedef struct _GeeHashSetIterator GeeHashSetIterator;
 typedef struct _GeeHashSetIteratorClass GeeHashSetIteratorClass;
 typedef struct _GeeHashSetIteratorPrivate GeeHashSetIteratorPrivate;
+
+struct _GeeHashSetNode {
+	gpointer key;
+	GeeHashSetNode* next;
+	guint key_hash;
+};
+struct _GeeHashSetIterator {
+	GObject parent_instance;
+	GeeHashSetIteratorPrivate * priv;
+};
+struct _GeeHashSetIteratorClass {
+	GObjectClass parent_class;
+};
+
+
 struct _GeeHashSetPrivate {
 	gint _array_size;
 	gint _nnodes;
@@ -50,8 +73,6 @@ enum  {
 	GEE_HASH_SET_G_DUP_FUNC,
 	GEE_HASH_SET_G_DESTROY_FUNC
 };
-static const gint GEE_HASH_SET_MIN_SIZE = 11;
-static const gint GEE_HASH_SET_MAX_SIZE = 13845163;
 static GeeHashSetNode** gee_hash_set_lookup_node (GeeHashSet* self, gconstpointer key);
 static gboolean gee_hash_set_real_contains (GeeCollection* base, gconstpointer key);
 static GType gee_hash_set_real_get_element_type (GeeIterable* base);
@@ -61,28 +82,8 @@ static gboolean gee_hash_set_real_remove (GeeCollection* base, gconstpointer key
 static void gee_hash_set_real_clear (GeeCollection* base);
 static void gee_hash_set_resize (GeeHashSet* self);
 static GObject * gee_hash_set_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
-struct _GeeHashSetNode {
-	gpointer key;
-	GeeHashSetNode* next;
-	guint key_hash;
-};
 static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash);
 static void gee_hash_set_node_free (GeeHashSetNode* self);
-
-#define GEE_HASH_SET_TYPE_ITERATOR (gee_hash_set_iterator_get_type ())
-#define GEE_HASH_SET_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_HASH_SET_TYPE_ITERATOR, GeeHashSetIterator))
-#define GEE_HASH_SET_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_HASH_SET_TYPE_ITERATOR, GeeHashSetIteratorClass))
-#define GEE_HASH_SET_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_HASH_SET_TYPE_ITERATOR))
-#define GEE_HASH_SET_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_HASH_SET_TYPE_ITERATOR))
-#define GEE_HASH_SET_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_HASH_SET_TYPE_ITERATOR, GeeHashSetIteratorClass))
-
-struct _GeeHashSetIterator {
-	GObject parent_instance;
-	GeeHashSetIteratorPrivate * priv;
-};
-struct _GeeHashSetIteratorClass {
-	GObjectClass parent_class;
-};
 struct _GeeHashSetIteratorPrivate {
 	GeeHashSet* _set;
 	gint _index;
@@ -115,15 +116,36 @@ static GeeSetIface* gee_hash_set_gee_set_parent_iface = NULL;
 static void gee_hash_set_dispose (GObject * obj);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
+static const gint GEE_HASH_SET_MIN_SIZE = 11;
+static const gint GEE_HASH_SET_MAX_SIZE = 13845163;
+
 
 GeeHashSet* gee_hash_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GHashFunc hash_func, GEqualFunc equal_func) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeHashSet * self;
-	self = g_object_newv (GEE_TYPE_HASH_SET, 0, NULL);
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_TYPE_HASH_SET, __params_it - __params, __params);
 	gee_hash_set_set_hash_func (self, hash_func);
 	gee_hash_set_set_equal_func (self, equal_func);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -175,6 +197,7 @@ static gboolean gee_hash_set_real_add (GeeCollection* base, gconstpointer key) {
 		guint hash_value;
 		gconstpointer _tmp1;
 		hash_value = self->priv->_hash_func (key);
+		_tmp1 = NULL;
 		*node = gee_hash_set_node_new ((_tmp1 = key, (_tmp1 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp1) : self->priv->g_dup_func (((gpointer) _tmp1)))), hash_value);
 		self->priv->_nnodes++;
 		gee_hash_set_resize (self);
@@ -191,6 +214,7 @@ static gboolean gee_hash_set_real_remove (GeeCollection* base, gconstpointer key
 	node = gee_hash_set_lookup_node (self, key);
 	if (*node != NULL) {
 		gpointer _tmp0;
+		_tmp0 = NULL;
 		(*node)->key = (_tmp0 = NULL, ((*node)->key == NULL || self->priv->g_destroy_func == NULL ? NULL : ((*node)->key = (self->priv->g_destroy_func ((*node)->key), NULL))), _tmp0);
 		*node = (*node)->next;
 		self->priv->_nnodes--;
@@ -208,7 +232,7 @@ static void gee_hash_set_real_clear (GeeCollection* base) {
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < self->priv->_array_size; i++) {
+		for (; i < self->priv->_array_size; i++) {
 			GeeHashSetNode* _tmp0;
 			GeeHashSetNode* node;
 			_tmp0 = NULL;
@@ -221,6 +245,7 @@ static void gee_hash_set_real_clear (GeeCollection* base) {
 				GeeHashSetNode* _tmp3;
 				_tmp1 = NULL;
 				next = (_tmp1 = node->next, node->next = NULL, _tmp1);
+				_tmp2 = NULL;
 				node->key = (_tmp2 = NULL, (node->key == NULL || self->priv->g_destroy_func == NULL ? NULL : (node->key = (self->priv->g_destroy_func (node->key), NULL))), _tmp2);
 				_tmp4 = NULL;
 				_tmp3 = NULL;
@@ -251,7 +276,7 @@ static void gee_hash_set_resize (GeeHashSet* self) {
 		{
 			gint i;
 			i = 0;
-			for (i = 0; i < self->priv->_array_size; i++) {
+			for (; i < self->priv->_array_size; i++) {
 				GeeHashSetNode* node;
 				GeeHashSetNode* next;
 				GeeHashSetNode* _tmp4;
@@ -338,6 +363,8 @@ static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash) {
 	gpointer _tmp1;
 	gpointer _tmp0;
 	self = g_slice_new0 (GeeHashSetNode);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
 	self->key = (_tmp1 = (_tmp0 = k, k = NULL, _tmp0), NULL, _tmp1);
 	self->key_hash = hash;
 	return self;
@@ -352,13 +379,31 @@ static void gee_hash_set_node_free (GeeHashSetNode* self) {
 
 
 static GeeHashSetIterator* gee_hash_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeHashSetIterator * self;
-	g_return_val_if_fail (set == NULL || GEE_IS_HASH_SET (set), NULL);
-	self = g_object_newv (GEE_HASH_SET_TYPE_ITERATOR, 0, NULL);
+	g_return_val_if_fail (GEE_IS_HASH_SET (set), NULL);
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_HASH_SET_TYPE_ITERATOR, __params_it - __params, __params);
 	gee_hash_set_iterator_set_set (self, set);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -383,6 +428,7 @@ static gpointer gee_hash_set_iterator_real_get (GeeIterator* base) {
 	self = GEE_HASH_SET_ITERATOR (base);
 	g_assert (self->priv->_stamp == self->priv->_set->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
+	_tmp0 = NULL;
 	return (_tmp0 = self->priv->_node->key, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0))));
 }
 
@@ -438,9 +484,9 @@ static void gee_hash_set_iterator_class_init (GeeHashSetIteratorClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = gee_hash_set_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_set_iterator_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_set_iterator_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_SET, g_param_spec_object ("set", "set", "set", GEE_TYPE_HASH_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
@@ -526,9 +572,9 @@ static void gee_hash_set_class_init (GeeHashSetClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_set_set_property;
 	G_OBJECT_CLASS (klass)->constructor = gee_hash_set_constructor;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_set_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_SIZE, "size");
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_HASH_FUNC, g_param_spec_pointer ("hash-func", "hash-func", "hash-func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_EQUAL_FUNC, g_param_spec_pointer ("equal-func", "equal-func", "equal-func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
