@@ -22,9 +22,27 @@
 
 #include <gee/readonlyset.h>
 
+
+#define GEE_READ_ONLY_SET_TYPE_ITERATOR (gee_read_only_set_iterator_get_type ())
+#define GEE_READ_ONLY_SET_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIterator))
+#define GEE_READ_ONLY_SET_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIteratorClass))
+#define GEE_READ_ONLY_SET_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_READ_ONLY_SET_TYPE_ITERATOR))
+#define GEE_READ_ONLY_SET_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_READ_ONLY_SET_TYPE_ITERATOR))
+#define GEE_READ_ONLY_SET_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIteratorClass))
+
 typedef struct _GeeReadOnlySetIterator GeeReadOnlySetIterator;
 typedef struct _GeeReadOnlySetIteratorClass GeeReadOnlySetIteratorClass;
 typedef struct _GeeReadOnlySetIteratorPrivate GeeReadOnlySetIteratorPrivate;
+
+struct _GeeReadOnlySetIterator {
+	GObject parent_instance;
+	GeeReadOnlySetIteratorPrivate * priv;
+};
+struct _GeeReadOnlySetIteratorClass {
+	GObjectClass parent_class;
+};
+
+
 struct _GeeReadOnlySetPrivate {
 	GeeSet* _set;
 	GType g_type;
@@ -46,21 +64,6 @@ static gboolean gee_read_only_set_real_contains (GeeCollection* base, gconstpoin
 static gboolean gee_read_only_set_real_add (GeeCollection* base, gconstpointer item);
 static gboolean gee_read_only_set_real_remove (GeeCollection* base, gconstpointer item);
 static void gee_read_only_set_real_clear (GeeCollection* base);
-
-#define GEE_READ_ONLY_SET_TYPE_ITERATOR (gee_read_only_set_iterator_get_type ())
-#define GEE_READ_ONLY_SET_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIterator))
-#define GEE_READ_ONLY_SET_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIteratorClass))
-#define GEE_READ_ONLY_SET_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_READ_ONLY_SET_TYPE_ITERATOR))
-#define GEE_READ_ONLY_SET_IS_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_READ_ONLY_SET_TYPE_ITERATOR))
-#define GEE_READ_ONLY_SET_ITERATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIteratorClass))
-
-struct _GeeReadOnlySetIterator {
-	GObject parent_instance;
-	GeeReadOnlySetIteratorPrivate * priv;
-};
-struct _GeeReadOnlySetIteratorClass {
-	GObjectClass parent_class;
-};
 struct _GeeReadOnlySetIteratorPrivate {
 	GType g_type;
 	GBoxedCopyFunc g_dup_func;
@@ -86,14 +89,33 @@ static GeeSetIface* gee_read_only_set_gee_set_parent_iface = NULL;
 static void gee_read_only_set_dispose (GObject * obj);
 
 
+
 GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeReadOnlySet * self;
 	g_return_val_if_fail (set == NULL || GEE_IS_SET (set), NULL);
-	self = g_object_newv (GEE_TYPE_READ_ONLY_SET, 0, NULL);
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_TYPE_READ_ONLY_SET, __params_it - __params, __params);
 	gee_read_only_set_set_set (self, set);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -177,11 +199,29 @@ static gpointer gee_read_only_set_iterator_real_get (GeeIterator* base) {
 
 
 static GeeReadOnlySetIterator* gee_read_only_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeReadOnlySetIterator * self;
-	self = g_object_newv (GEE_READ_ONLY_SET_TYPE_ITERATOR, 0, NULL);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_READ_ONLY_SET_TYPE_ITERATOR, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -222,9 +262,9 @@ static void gee_read_only_set_iterator_class_init (GeeReadOnlySetIteratorClass *
 	g_type_class_add_private (klass, sizeof (GeeReadOnlySetIteratorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_set_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_read_only_set_iterator_set_property;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 
@@ -295,9 +335,9 @@ static void gee_read_only_set_class_init (GeeReadOnlySetClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_set_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_read_only_set_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_read_only_set_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_SIZE, "size");
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_SET, g_param_spec_object ("set", "set", "set", GEE_TYPE_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
